#
# spec file for package clzip
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           clzip
Version:        1.11~rc1
Release:        28.1
%define xversion	1.11-rc1
Summary:        Lossless Data Compressor based on LZMA
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Compression
URL:            http://www.nongnu.org/lzip/clzip.html
Source:         http://download.savannah.gnu.org/releases/lzip/clzip/%name-%xversion.tar.gz
#Source2:        http://download.savannah.gnu.org/releases/lzip/clzip/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): info
Requires(preun):info

%description
Clzip is a lossless data compressor based on the LZMA algorithm, with
very safe integrity checking and a user interface similar to that of
gzip or bzip2. Clzip decompresses almost as fast as gzip and
compresses better than bzip2, which makes it well suited for software
distribution and data archiving. Clzip uses the lzip file format; the
files produced by clzip are fully compatible with lzip-1.4 or newer.
Clzip is, in fact, a C language implementation of lzip, intended for
embedded devices or systems lacking a C++ compiler.

%prep
%autosetup -n %name-%xversion

%build
# not autoconf
mkdir build
pushd build/
../configure --prefix="%_prefix" --bindir="%_bindir" --datadir="%_datadir" \
	--infodir="%_infodir" --mandir="%_mandir" --sysconfdir="%_sysconfdir" \
	CC="%__cc" CFLAGS="%optflags"
make %{?_smp_flags}
popd

%install
pushd build/
%make_install
popd

%check
pushd build/
make %{?_smp_mflags} check
popd

%post
%install_info --info-dir="%_infodir" "%_infodir/clzip.info%ext_info"

%preun
%install_info_delete --info-dir="%_infodir" "%_infodir/clzip.info%ext_info"

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README
%_bindir/clzip
%_mandir/man1/clzip.1%ext_man
%_infodir/clzip.info%ext_info

%changelog
* Fri Dec 14 2018 jengelh@inai.de
- Update to new upstream release 1.11~rc1
  * Detection of forbidden combinations of characters in trailing
    data has been improved.
* Mon Mar  5 2018 jengelh@inai.de
- Update to new upstream release 1.10
  * The option "--loose-trailing" has been added.
  * The test used by clzip to discriminate trailing data from a
    corrupt header in multimember or concatenated files has been
    improved to a Hamming distance of 3.
  * The "-S" option now keeps input files unchanged.
* Thu May 11 2017 mpluskal@suse.com
- Update to version 1.9:
  * The option '-l, --list' has been ported from lziprecover.
  * It is now an error to specify two or more different operations
    in the command line (--decompress, --list or --test).
  * Compression time of option '-0' has been reduced by 6%%.
  * Compression time of options '-1' to '-9' has been reduced by 1%%.
  * Decompression time has been reduced by 7%%.
  * In test mode, clzip now continues checking the rest of the
    files if any input file is a terminal.
  * Trailing data are now shown both in hexadecimal and as a string
    of printable ASCII characters.
  * Three missing chapters have been added to the manual, which
    now contains all the chapters of the lzip manual.
* Sat May 28 2016 mpluskal@suse.com
- Update to version 1.8:
  * main.c: Added new option '-a, --trailing-error'.
  * main.c (decompress): Print up to 6 bytes of trailing data
    when '-vvvv' is specified.
  * decoder.c (LZd_verify_trailer): Removed test of final code.
  * main.c (main): Delete '--output' file if infd is a terminal.
  * main.c (main): Don't use stdin more than once.
  * lzip.texi: Added chapter 'Trailing data'.
  * configure: Avoid warning on some shells when testing for gcc.
  * Makefile.in: Detect the existence of install-info.
  * testsuite/check.sh: A POSIX shell is required to run the tests.
  * testsuite/check.sh: Don't check error messages.
- Run internal testsuite
* Thu Aug  6 2015 jengelh@inai.de
- Update to new upstream release 1.7
  * The option "-0", which produces a compression speed and ratio
  comparable to those of gzip, has been ported from lzip.
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 1.6
  * Compression ratio of option -9 has been slightly increased.
  * Copying of file dates, permissions, and ownership now behaves
  like `cp -p`. (If the user ID or the group ID cannot be
  duplicated, the file permission bits S_ISUID and S_ISGID are
  cleared).
  * The license has been changed to GPL version 2 or later.
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Wed Oct  2 2013 jengelh@inai.de
- Update to new upstream release 1.5
  * Clzip now shows the progress of compression at verbosity
  level 2 (-vv).
* Sat Jun  8 2013 jengelh@inai.de
- Use more robust make install call; remove redundant %%clean
  section; wrap description at 70 cols; GPG signature verification
* Mon Apr  1 2013 pascal.bleser@opensuse.org
- update to 1.4:
  * Multi-step trials have been implemented
  * Compression ratio has been slightly increased
  * Compression time has been reduced by 10%%
  * Decompression time has been reduced by 8%%
* Thu Mar 29 2012 pascal.bleser@opensuse.org
- update to 1.3:
  * inability to change output file attributes has been downgraded from error
    to warning
  * a small change has been made in the "--help" output and man page
* Mon May 23 2011 pascal.bleser@opensuse.org
- initial version (1.2)
